package com.ozs.pm.service.impl;

import java.util.*;

import com.ozs.common.utils.DateUtils;
import com.ozs.common.utils.bean.BeanUtils;
import com.ozs.pm.doman.PmDemand;
import com.ozs.pm.doman.vo.requestVo.PmRequestVo;
import com.ozs.pm.doman.vo.responseVo.PmDemandResponseVo;
import com.ozs.pm.mapper.PmDemandMapper;
import com.ozs.pm.service.IPmDemandService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;


/**
 * 采购需求Service业务层处理
 *
 * @author ruoyi
 * @date 2023-01-16
 */
@Service
public class PmDemandServiceImpl implements IPmDemandService
{
    @Autowired
    private PmDemandMapper pmDemandMapper;

    /**
     * 查询采购需求
     *
     * @param demandId 采购需求主键
     * @return 采购需求
     */
    @Override
    public PmDemandResponseVo selectPmDemandByDemandId(Long demandId)
    {
        PmDemand pmDemand = pmDemandMapper.selectPmDemandByDemandId(demandId);
        if(pmDemand != null){
            PmDemandResponseVo vo = new PmDemandResponseVo();
            BeanUtils.copyProperties(pmDemand, vo);

            return vo;
        } else {
            return null;
        }
    }

    /**
     * 查询采购需求列表
     *
     * @param requestVo
     * @return 采购需求
     */
    @Override
    public List<PmDemandResponseVo> selectPmDemandList(PmRequestVo requestVo)
    {
        PmDemand pmDemand = new PmDemand();
        pmDemand.setProjectName(requestVo.getProjectName());
        pmDemand.setPurchaseServices(requestVo.getPurchaseServiceStation());
        pmDemand.setProjectStatus(requestVo.getProjectStatus());
        Map<String,Object> params = new HashMap<>();
        params.put("beginDate",requestVo.getBeginDate());
        params.put("endDate",requestVo.getEndDate());
        pmDemand.setParams(params);
        List<PmDemand> pmDemandList = pmDemandMapper.selectPmDemandList(pmDemand);
        List<PmDemandResponseVo> pmDemandResponseVoList = new ArrayList<>();
        if(pmDemandList != null && !pmDemandList.isEmpty()){
            for(PmDemand pmDemand1 : pmDemandList){
                PmDemandResponseVo vo = new PmDemandResponseVo();
                BeanUtils.copyBeanProp(pmDemand1,vo);
                pmDemandResponseVoList.add(vo);
            }
        }
        return pmDemandResponseVoList;
    }

    /**
     * 新增采购需求
     *
     * @param pmDemand 采购需求
     * @return 结果
     */
    @Override
    public int insertPmDemand(PmDemand pmDemand)
    {
        pmDemand.setCreateTime(DateUtils.getNowDate());
        return pmDemandMapper.insertPmDemand(pmDemand);
    }

    /**
     * 修改采购需求
     *
     * @param pmDemand 采购需求
     * @return 结果
     */
    @Override
    public int updatePmDemand(PmDemand pmDemand)
    {
        pmDemand.setUpdateTime(DateUtils.getNowDate());
        return pmDemandMapper.updatePmDemand(pmDemand);
    }

}
